@@ -4,6 +4,7 @@ import numpy as np
 import pandas as pd
 from scipy import stats
 from sklearn.preprocessing import LabelEncoder
+from tqdm import tqdm
 
 from automl_tools.functions.utils import target_count_class, iqr_outliers, zr_score_outlier, winsorization_outliers, get_tabulate, generate_id
 
@@ -56,27 +57,27 @@ def get_dataset_statistical(train, test, id_col, target_col):
 
     id_columns.append(id_col)
 
-    for col in train.columns:
+    for col in tqdm(train.columns):
         if train[col].dtype == 'datetime64[ns]':
             date_columns.append(col)
 
-    for col in train.select_dtypes('number').columns:
+    for col in tqdm(train.select_dtypes('number').columns):
         if train[col].value_counts().shape[0] == 2:
             numeric_binary_columns.append(col)
-        elif 2 < train[col].value_counts().shape[0] <= 50:
-            numeric_continuous_columns.append(col)
-        elif int(train[col].value_counts().shape[0]) == int(total_rows):
+        elif 2 < train[col].value_counts().shape[0] <= 10:
+            numeric_discrete_columns.append(col)
+        elif int(train[col].value_counts().shape[0]) == int(total_rows) or int(train[col].value_counts().shape[0]) == 1:
             uniques_columns.append(col)
         else:
-            numeric_discrete_columns.append(col)
+            numeric_continuous_columns.append(col)
 
-    for col in train.select_dtypes('category').columns:
+    for col in tqdm(train.select_dtypes('category').columns):
         if train[col].value_counts().shape[0] == 2:
             category_binary_columns.append(col)
         else:
             category_nominal_columns.append(col)
 
-    for col in list(train):
+    for col in tqdm(list(train)):
         if (len(train[col].value_counts()) == 1) | (train[col].isnull().sum() / len(train) >= 0.90):
             missing_columns.append(col)
 
@@ -107,7 +108,7 @@ def get_dataset_resume_table(train, test):
 
     t = list()
 
-    for col in train.columns:
+    for col in tqdm(train.columns):
         train_dtype = train[col].dtypes
         train_unique_list = list(train[col].unique())
         train_total_uniques = len(train[col].unique())
@@ -150,7 +151,7 @@ def get_dataset_outlier(train, test):
     test_total_values = test.shape[0]
 
     t = list()
-    for col in train.select_dtypes('number').columns:
+    for col in tqdm(train.select_dtypes('number').columns):
         train_dtype = train[col].dtypes
         train_zr_score_outlier = zr_score_outlier(train[col])
         train_winsorization_outliers = winsorization_outliers(train[col])
@@ -178,7 +179,7 @@ def get_dataset_outlier(train, test):
 def get_dataset_outlier_processing(train, test):
     pd.options.mode.chained_assignment = None
 
-    for col in train.select_dtypes('number').columns:
+    for col in tqdm(train.select_dtypes('number').columns):
         is_out = iqr_outliers(train[col])
         if is_out == "yes":
             first_quartile, third_quartile = np.percentile(train[col], [25, 75])
