@@ -27,15 +27,13 @@ def search_model(model_name, model_type, _num_class):
     num_leaves = 2 ^ max_depth - 1
     if model_type in ("binary", "multi_class"):
         XGB = XGBClassifier(objective="binary:logistic", eval_metric="error",
-                            use_label_encoder=False, max_depth=max_depth,
+                            max_depth=max_depth,
                             n_estimators=100, learning_rate=0.05)
         LGB = LGBMClassifier(objective="binary", metric="logloss", num_class=_num_class,
                              max_depth=max_depth, num_leaves=num_leaves,
                              n_estimators=100, learning_rate=0.05)
         CTB = CatBoostClassifier(loss_function="Logloss", eval_metric="AUC", verbose=0,
-                                 allow_writing_files=False,
-                                 max_depth=max_depth, leaf_estimation_method='Newton',
-                                 thread_count=n_jobs, learning_rate=0.05)
+                                 allow_writing_files=False, max_depth=max_depth, learning_rate=0.05)
         NGB = NGBClassifier(Dist=Bernoulli, verbose=False)
 
         if model_name == "XGB":
@@ -62,9 +60,9 @@ def search_model(model_name, model_type, _num_class):
             LR=LogisticRegression(),
             RF=RandomForestClassifier(max_depth=max_depth, n_estimators=100),
             SVM=SVC(probability=True),
-            LS=SGDClassifier(loss="log", penalty="l1"),
-            RD=SGDClassifier(loss="log", penalty="l2"),
-            NET=SGDClassifier(loss="log", penalty="elasticnet"),
+            LS=SGDClassifier(penalty="l1"),
+            RD=SGDClassifier(penalty="l2"),
+            NET=SGDClassifier(penalty="elasticnet"),
             DT=DecisionTreeClassifier(max_depth=max_depth),
             ET=ExtraTreesClassifier(max_depth=max_depth, n_estimators=100),
             GB=GradientBoostingClassifier(max_depth=max_depth, n_estimators=100),
@@ -108,7 +106,7 @@ def model_selection_support(train, target, model_names, model_type, _num_class):
     x_train, x_val, y_train, y_val = train_test_split(train, target, test_size=0.20, random_state=2021)
 
     feat_labels = train.columns.tolist()
-    global model_based, clf
+    global model_based
     selection_list = list()
     feature_name = list()
 
@@ -117,7 +115,7 @@ def model_selection_support(train, target, model_names, model_type, _num_class):
         if model_type in ("binary", "multi_class"):
             clf = search_model(model_name, model_type, _num_class)
             model_based = SelectFromModel(clf, threshold='median')
-        if model_type == "regression":
+        elif model_type == "regression":
             clf = search_model(model_name, model_type, _num_class)
             model_based = SelectFromModel(clf, threshold='median')
 
