@@ -6,6 +6,7 @@ import pandas as pd
 import seaborn as sns
 from IPython.core.display import display
 from scipy import stats
+from scipy.stats import rankdata
 from sklearn.metrics import roc_auc_score, roc_curve, average_precision_score, precision_recall_curve, confusion_matrix
 
 
@@ -136,6 +137,14 @@ def target_count_class(target):
     return model_type, count_class, name_class
 
 
+def rank_predictions(predictions, cv):
+    rank_predictions_test = np.zeros((predictions.shape[0], 1))
+    for i in range(cv):
+        rank_predictions_test[:, 0] = np.add(rank_predictions_test[:, 0], rankdata(predictions[:, i].reshape(-1, 1)) / rank_predictions_test.shape[0])
+    rank_predictions_test /= cv
+    return rank_predictions_test
+
+
 def display_roc_curve(y_, oof_preds_, folds_idx_, model_name):
     plt.figure(figsize=(6, 6))
     scores = []
@@ -157,7 +166,7 @@ def display_roc_curve(y_, oof_preds_, folds_idx_, model_name):
     plt.title(f'{model_name.upper()} ROC CURVE')
     plt.legend(loc="lower right")
     plt.tight_layout()
-    plt.savefig(f'roc_curve_{model_name}.png')
+    plt.savefig(f'{model_name}_roc_curve.png')
     plt.show()
 
 
@@ -182,7 +191,7 @@ def display_precision_recall(y_, oof_preds_, folds_idx_, model_name):
     plt.title(f'{model_name} Recall / Precision')
     plt.legend(loc="best")
     plt.tight_layout()
-    plt.savefig(f'recall_precision_curve_{model_name}.png')
+    plt.savefig(f'{model_name}_recall_precision_curve.png')
     plt.show()
 
 
@@ -201,7 +210,7 @@ def display_importance(feature_importance_, model_name):
 
 def ks_report(data=None, target=None, prob=None):
     data['target0'] = 1 - data[target]
-    data['bucket'] = pd.qcut(data[prob], 10)
+    data['bucket'] = pd.qcut(data[prob].rank(method='first'), 10)
     grouped = data.groupby('bucket', as_index=False)
     ks_table = pd.DataFrame()
     ks_table['min_prob'] = grouped.min()[prob]
@@ -218,8 +227,8 @@ def ks_report(data=None, target=None, prob=None):
     # formatting
     ks_table['cum_event_rate'] = ks_table['cum_event_rate'].apply('{0:.2%}'.format)
     ks_table['cum_nonevent_rate'] = ks_table['cum_nonevent_rate'].apply('{0:.2%}'.format)
-    ks_table.index = range(1, 11)
-    ks_table.index.rename('Decile', inplace=True)
+    ks_table = generate_id(ks_table)
+    ks_table.rename({'NEW_ID': 'decile'}, axis=1, inplace=True)
 
     # display KS
     from colorama import Fore
