@@ -4,7 +4,7 @@ from sklearn.model_selection import StratifiedKFold, KFold
 from automl_tools.functions.imputation import get_dataset_missing_processing, get_dataset_binding_processing
 from automl_tools.functions.logger import seed_everything, get_stage, get_logger
 from automl_tools.functions.modeling import run_model
-from automl_tools.functions.optimization import get_dataset_parameter_baseline
+from automl_tools.functions.parameter import get_dataset_parameter
 from automl_tools.functions.prepare import get_dataset_remove_low_information, get_dataset_remove_correlation
 from automl_tools.functions.processing import get_dataset_info, get_dataset_resume_table, get_dataset_statistical, get_dataset_outlier, get_dataset_outlier_processing
 from automl_tools.functions.selection import get_dataset_feature_selection
@@ -17,11 +17,11 @@ def automl_run(train=pd.DataFrame,
                test=pd.DataFrame,
                id_col=None,
                target_col="target",
-               imp_num="knn",
-               imp_cat="knn",
+               imp_num=None,
+               imp_cat=None,
                processing=None,
-               mutual_information=False,
-               correlation_drop=False,
+               mutual_information=None,
+               correlation_drop=None,
                model_feature_selection=None,
                model_run="LR",
                augmentation=False,
@@ -32,11 +32,11 @@ def automl_run(train=pd.DataFrame,
     :type test: DataFrame
     :type id_col: String -> Default: None
     :type target_col: String
-    :type imp_num: String ["gaussian", "arbitrary", "median", "mean", "random", "knn"] -> Default: "knn"
-    :type imp_cat: String ["frequent", "constant", "rare", "knn"] -> Default: "knn"
-    :type processing: String : ["woe", "binding" ]-> Default: False
-    :type mutual_information: Boolean : [True, False]-> Default: False
-    :type correlation_drop: Boolean : [True, False]-> Default: False
+    :type imp_num: String ["gaussian", "arbitrary", "median", "mean", "random", "knn"] -> Default: None
+    :type imp_cat: String ["frequent", "constant", "rare", "knn"] -> Default: None
+    :type processing: String : ["woe", "binding" ]-> Default: None
+    :type mutual_information: Boolean : [True, False]-> Default: None
+    :type correlation_drop: Boolean : [True, False]-> Default: None
     :type model_feature_selection: List :
         paramter:
             binary:
@@ -135,7 +135,7 @@ def automl_run(train=pd.DataFrame,
     get_stage(13)
     get_stage(14)
     logger.info('Load feature optimization')
-    best_parameter_tuning = get_dataset_parameter_baseline(_train, _target, feature_name, model_run)
+    best_parameter_tuning = get_dataset_parameter(_train, _target, feature_name, model_run)
 
     get_stage(15)
     logger.info('Load cross-validation')
@@ -146,7 +146,7 @@ def automl_run(train=pd.DataFrame,
 
     logger.info('Load run model')
     model_dict = run_model(_train, _test, _target, _id_train, _id_test, folds, augmentation,
-                           feature_name, model_run, best_parameter_tuning)
+                           feature_name, model_run, best_parameter_tuning, cv)
 
     logger.info('generate report')
     display_importance(feature_importance_=model_dict.get("feature_importance_"),
@@ -182,10 +182,10 @@ def automl_run(train=pd.DataFrame,
                              normalize=True,
                              model_name=model_run)
 
-    model_dict.get("oof_train_preds").to_csv("trained.csv", index=False)
-    model_dict.get("oof_test_preds").to_csv("submission.csv", index=False)
+    model_dict.get("oof_train_preds").to_csv(f"{model_run}_trained.csv", index=False)
+    model_dict.get("oof_test_preds").to_csv(f"{model_run}_submission.csv", index=False)
 
     _ks_report = ks_report(data=model_dict.get("oof_train_preds"),
                            target="target",
                            prob="prediction")
-    _ks_report.to_csv("ks_report.csv", index=False)
+    _ks_report.to_csv(f"{model_run}_ks_report.csv", index=False)
